import type { ConversionEvent } from './conversionEvent';
/**
 * Use this event to track when users convert after a previous Algolia request. For example, a user clicks on an item in the search results to view the product detail page. Then, the user adds the item to their shopping cart.  If you\'re building your category pages with Algolia, you\'ll also use this event.
 */
export type ConvertedObjectIDsAfterSearch = {
    /**
     * Can contain up to 64 ASCII characters.   Consider naming events consistently—for example, by adopting Segment\'s [object-action](https://segment.com/academy/collecting-data/naming-conventions-for-clean-data/#the-object-action-framework) framework.
     */
    eventName: string;
    eventType: ConversionEvent;
    /**
     * Name of the Algolia index.
     */
    index: string;
    /**
     * List of object identifiers for items of an Algolia index.
     */
    objectIDs: string[];
    /**
     * Unique identifier for a search query.  The query ID is required for events related to search or browse requests. If you add `clickAnalytics: true` as a search request parameter, the query ID is included in the API response.
     */
    queryID: string;
    /**
     * Anonymous or pseudonymous user identifier.   > **Note**: Never include personally identifiable information in user tokens.
     */
    userToken: string;
    /**
     * Time of the event in milliseconds in [Unix epoch time](https://wikipedia.org/wiki/Unix_time). By default, the Insights API uses the time it receives an event as its timestamp.
     */
    timestamp?: number;
};
//# sourceMappingURL=convertedObjectIDsAfterSearch.d.ts.map